#!/usr/bin/gnuplot

set colors classic
set term x11

set xl "diameter {/Helvetica-Oblique D} / km"
set yl "number of bodies {/Helvetica-Oblique N} (>{/Helvetica-Oblique D})" offset -0.5,0

set xr [0.8*0.001:2000]
y1=0.5
y2=1.e14
set yr [y1:y2]
set logscale xy
set xtics 10
set ytics 10
set mxtics 10
set mytics 10
set tics format "10^{%T}"
set tics front
set key at graph 0.99,graph 0.98 samplen 1.5 spacing 1.6 font "Helvetica,18"

set style line 1 lc rgb '#0066ff' lw 2 pt 1		# evolved MB
set style line 2 lc rgb '#000066' lw 2 pt 1		# evolved Themis
set style line 3 lc rgb '#999999' lw 1 pt 1		# evolved NEA
set style line 4 lc rgb '#ccaaaa' lw 4 dt 3		# initial MB
set style line 5 lc rgb '#bbbbff' pt 7 ps 0.8		# observed MB
set style line 6 lc rgb '#cccccc' pt 7 ps 0.8		# observed NEA

set lmargin 7.5
set rmargin 0.5
set bmargin 3.0
set tmargin 1.6

set arrow from 1.0,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-3,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from 1.0e-7,graph 0 rto 0,graph 1 nohead lt 0 front
set arrow from graph 0,first 1.0 rto graph 1,first 0 nohead lt 0 front

p \
  "<awk '(FNR==1){ print \"\"; } ($2==1)' ../*[0-9]*/tmp/2000.000.out | ./hc.awk" u 1:2 w l ls 1 t "evolved MB",\
  "<awk '(FNR==1){ print \"\"; } ($2==3)' ../*[0-9]*/tmp/2000.000.out | ./hc.awk" u 1:2 w l ls 2 t "evolved Themis",\
  "<./hc_sfd.awk ../src/sfd1.dat_EDITED" u 1:2 w l ls 4 t "initial MB"    ,\
  "<./hc_sfd.awk ../src/sfd3.dat_EDITED" u 1:2 w l ls 4 t "initial Themis",\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "../../dat/Bottke_etal_2015.dat"  u (10.**$1):(10.**$2) w p ls 5 t "{/=14 Bottke etal. (2015)}",\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p lc rgb '#ffffff' pt 7 ps 1.0 not,\
  "<awk '($1>-1) && ($1<0.2)' ../../dat/Gladman_etal_2009.dat" u (10.**$1):(10.**$2*1.5) w p ls 5 not,\
  "../src/24_Themis_family.dat_hc" u 1:2 w l ls 5 lw 3 t "observed Themis",\

pa -1

set term postscript eps enh color solid "Helvetica" 18
set out "sfd_2000.000.eps"
set size 0.625*1.5,0.925*1.5
rep

system("eps2png sfd_2000.000.eps")

q


  "<echo 100.e-9 9.7e24" w p pt 1 ps 3 lw 8 lc '#0066ff' t "zodiacal cloud",\
  "<echo 100.e-9 1.3e24" w p pt 1 ps 3 lw 8 lc '#cc00ff' t "IRAS 2.1{/Symbol\260} band",\

#tmp=1.0e-6; set arrow from tmp,3.4e20 to tmp,7.0e19 size graph 0.01,30 front filled lw 3 lc '#ccaaaa'
#tmp=1.0e-4; set arrow from tmp,5.2e14 to tmp,2.1e14 size graph 0.005,30 front filled lw 3 lc '#ccaaaa'

  f_family1(x) not lc 'gray'    dt 2,\
  f_family2(x) not lc 'gray'    dt 2

